..  Index of the Raschii documentation
    The page uses the README in the main folder
    but substitutes the documentation section with
    a table of contents

.. ##############################################################

.. include:: ../README.rst
   :end-before: TOC_STARTS_HERE

.. ##############################################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   theory
   usage
   usage_command_line
   raschii_dart
   api_docs

.. ##############################################################

.. include:: ../README.rst
   :start-after: TOC_ENDS_HERE
